// Your favorite mail applications names ("Thunderbird", "Evolution", "Geary"...).
// You can add your own or set the following list like you want.
const mailAppNames = ["Thunderbird", "Evolution", "Geary"];
const mailAppNamesCounter = mailAppNames.length;

const St = imports.gi.St;
const Clutter = imports.gi.Clutter;
const Main = imports.ui.main;
const Lang = imports.lang;
const MessageTray = imports.ui.messageTray;


const MessageCounterIndicator = new Lang.Class({

    Name: 'MailIndicator',

    _init: function() {
    	
        this.actor = new St.Bin({style_class: 'panel-button', visible: true});
        
        this.icon = new St.Icon({icon_name: 'mail-read-symbolic', style_class: 'system-status-icon'});
        							
        this.actor.set_child(this.icon);
        
        this._sources = [];

        Main.messageTray.connect('source-added', Lang.bind(this, this._onSourceAdded));
        Main.messageTray.connect('source-removed', Lang.bind(this, this._onSourceRemoved));
        Main.messageTray.connect('queue-changed', Lang.bind(this, this._updateCount));

        let sources = Main.messageTray.getSources();
        sources.forEach(Lang.bind(this, function(source) {this._onSourceAdded(null, source);}));
        
    },

    _onSourceAdded: function(tray, source) {
        source.connect('count-updated', Lang.bind(this, this._updateCount));
        this._sources.push(source);
        this._updateCount();
    },

    _onSourceRemoved: function(tray, source) {
        this._sources.splice(this._sources.indexOf(source), 1);
        this._updateCount();
    },

    _updateCount: function() {
        let count = 0;

        this._sources.forEach(Lang.bind(this,
            function(source) {
            	for(var i=0; i<mailAppNamesCounter; i++) {
            		if (source.title.includes(mailAppNames[i])) {
                		count++;
                	}
              	}
            }));
            
        let mail_icon;
        
        if (count > 0) {
        	mail_icon = 'mail-mark-important-symbolic';
        	} else {
        	mail_icon = 'mail-read-symbolic';
        };
        
        this.icon.icon_name = mail_icon;
        
    }
});

let count_indicator;

function init() {
}

function enable() {

	let centerBox = Main.panel._centerBox;
    count_indicator = new MessageCounterIndicator();
    centerBox.add_actor(count_indicator.actor);

}

function disable() {
    
	let centerBox = Main.panel._centerBox;
	centerBox.remove_actor(count_indicator.actor);
    
}
